@@ -137,17 +137,16 @@ def recvmsg(pipe):
 
 
 def multiproc_child_perform(edge, fwd, pipe):
-
     try:
 
         mgr = EdgeMultiprocParentProxy(pipe)
-        logger = Logger(mgr, "edge-%d" % edge._eid)
+        logger = Logger(mgr, ["edge-%d" % edge._eid])
 
         sendmsg(pipe, PROXYMSG.C2P_BEG, pid=os.getpid())
 
-        logger.debug("before edge run")
+        logger.debug("multiproc edge begin")
         out, fwd = edge.run(mgr, fwd) 
-        logger.debug("after edge run")
+        logger.debug("multiproc edge end")
 
         sendmsg(pipe, PROXYMSG.C2P_END, pid=os.getpid(),
                     output=out, forward=fwd)
